Module resolve

Module resolve 

Namespace-aware name resolution for use imports.

Structs

NameResolver
Tracks the current namespace and use imports and resolves names against them.

Enums

NameContext
Which import table a name is looked up in.
ResolvedName
Result of resolving a name against the current namespace and imports.