Module visitor
php_ast
0.2.1
Module visitor
Module Items
Traits
Functions
In crate php_
ast
php_ast
Module
visitor
Traits

Visitor
Visitor trait for AST traversal. All methods have default implementations that recursively walk child nodes, so implementors only need to override the node types they care about.
Functions

walk_
arg
walk_
class_
member
walk_
enum_
member
walk_
expr
walk_
param
walk_
program
walk_
property_
hook
walk_
stmt